---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: 'enhancement'
assignees: ''

---
## Problem

<!-- What problem do you currently face so that you want this feature? -->

<!-- Are there existing features close to solving this problem? Why don't they work? -->


## Proposal

<!-- Describe the solution you would like to have. -->

<!-- Provide a code snippet showing the new feature in action, at least as an idea. -->

```python
import kopf
```

<!-- Are there any other ways of achieving the same goal? 
     Why is this proposal better than those alternatives? -->


## Checklist

- [ ] Many users can benefit from this feature, it is not a one-time case
- [ ] The proposal is related to the K8s operator framework, not to the K8s client libraries
